## Introduction

This library provides a pure Python interface for the RocketAPI. It's compatible with Python versions **3.7+**.

## Installing

You can install or upgrade `rocketapi` via

```bash
pip install rocketapi --upgrade
```

## Usage

See the [documentation](https://docs.rocketapi.io) for more information.
